<?php
/**
 * WPSDAlexaRank. Ranking on Alexa.
 * @author dligthart <info@daveligthart.com>
 * @version 0.1
 * @package wp-stats-dashboard
 *
 *
 * <code>
$a = new WPSDAlexaRank('http://alexa.com/xml/dad?url=','digg.com'); // domain only!
echo 'Rank :: '.$a->get('rank'); // returns 118
echo '';
echo 'Reach :: '.$a->get('reach'); // returns 95
echo '';
echo 'Links In :: '.$a->get('linksin'); // returns 34,414
*  </code>
*/
class WPSDAlexaRank extends WPSDStats {

	var $xml;
	var $values;
	var $address = 'http://data.alexa.com/data?cli=10&dat=snbamz&url=';

	/**
	 * WPSDAlexaRank.
	 * @param string $domain
	 * @param boolean $curl
	 */
	function WPSDAlexaRank($domain, $curl = false) {
		parent::WPSDStats();
		
		if($this->isOutdated()) {
			if(!$curl){
				$this->xml = $this->get_data($domain);
			} else {
				$this->xml = $this->get_data_curl($domain);
			}		
			$this->set();
		} else {
			$this->set_cached();
		}	
	}

	/**
	 * Get data from alexa.
	 * @param string $domain
	 * @access public
	 */
	function get_data($domain) {
		$url = $this->address.'http://'.$domain;
		$xml = file_get_contents($url);
		return $xml;
	}

	/**
	 * Set data.
	 */
	function set() {
		$this->values['rank'] = (preg_match('/POPULARITY URL="[a-z0-9\\-\\.\\/]{1,}" TEXT="([0-9]{1,12})"/',$this->xml,$regs) ? number_format($regs[1]) : 0);
		$this->values['reach'] = (preg_match('/REACH RANK="([0-9]{1,12})"/',$this->xml,$regs) ? number_format($regs[1]) : 0);
		$this->values['linksin'] = (preg_match('/LINKSIN NUM="([0-9]{1,12})"/',$this->xml,$regs) ? number_format($regs[1]) : 0);
		
		$this->set_cache('alexa_rank', $this->values['rank']);
		$this->set_cache('alexa_reach', $this->values['reach']);
		$this->set_cache('alexa_linksin', $this->values['linksin']);
	}
	
	function set_cached() {
		$this->values['rank'] = $this->get_cache('alexa_rank');
		$this->values['reach'] = $this->get_cache('alexa_reach');
		$this->values['linksin'] = $this->get_cache('alexa_linksin');
	}

	/**
	 * Get data.
	 * @return value
	 * @access protected
	 */
	function get($value){
		return (isset($this->values[$value]) ? $this->values[$value] : '0');
	}

	/**
	 * Get rank.
	 * @return rank
	 * @access public
	 */
	function getRank() {
		return $this->get('rank');
	}

	/**
	 * Get reach.
	 * @return reach
	 * @access public
	 */
	function getReach() {
		return $this->get('reach');
	}

	/**
	 * Get Links in.
	 * @return linksin
	 * @access public
	 */
	function getLinksIn() {
		return $this->get('linksin');
	}

	/**
	 * Get data by curl.
	 * @param string $domain
	 * @access public
	 */
	function get_data_curl($domain) {
		$xml = '';
		if(function_exists('curl_init')) {
			ob_start();
			$url = $this->address.$domain;
			$ch = curl_init();
			$timeout = 5;
			curl_setopt($ch,CURLOPT_URL, $url);
			curl_setopt($ch,CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch,CURLOPT_CONNECTTIMEOUT, $timeout);
			$xml = curl_exec($ch);
			curl_close($ch);
			ob_end_clean();
		}
		return $xml;
	}
}
?>