<?php
/**
 * WPSDBacktype.
 * @author dligthart <info@daveligthart.com>
 * @version 0.1
 * @package wp-stats-dashboard
 */
class WPSDBacktype extends WPSDStats {

	var $xml;
	var $values;
	var $address = '';

	/**
	 * WPSDBacktype.
	 * @param string $domain
	 * @param boolean $curl
	 */
	function WPSDBacktype($domain, $curl = false) {	
		parent::WPSDStats();
				
		$domain = str_replace('http://', '', $domain);
		$domain = str_replace('https://', '', $domain);
		
		$this->address = "http://www.backtype.com/connect/" . $domain;
		
		if($this->isOutdated()) {
			if(!$curl){
				$this->xml = $this->get_data($domain);
			} else {
				$this->xml = $this->get_data_curl($domain);
			}
	
			$this->set();
		} else {
			$this->set_cached();
		}
	}

	
	function get_data($domain) {
		$url = $this->address;
		$xml = file_get_contents($url);
		return $xml;
	}

	function set() {

		preg_match("@>([\d]*?) Other Comments</a>@si", $this->xml, $matches);

		$c = strip_tags(trim($matches[1]));
		
		preg_match("@>([\d]*?) Tweets</a>@si", $this->xml, $matches);
		
		$t = strip_tags(trim($matches[1]));
		
		$this->values['comments'] = $c;
		
		$this->values['tweets'] = $t;

		$this->set_cache('backtype_comments', $this->values['comments'] );
		
		$this->set_cache('backtype_tweets', $this->values['tweets']);
	}
	
	function set_cached() {
		
		$this->values['comments'] = $this->get_cache('backtype_comments');
		
		$this->values['tweets'] = $this->get_cache('backtype_tweets');
	}

	
	function get($value){
		return (isset($this->values[$value]) ? $this->values[$value] : '0');
	}

	function getComments() {
		return $this->get('comments');
	}
	
	function getTweets() {
		return $this->get('tweets');
	}
	
	/**
	 * Get address.
	 * @return address
	 * @access public
	 */
	function getAddress() {
		return $this->address;
	}
	
	function getHomeAddress() {
		return $this->address;
	}

	/**
	 * Get data by curl.
	 * @param string $domain
	 * @access public
	 */
	function get_data_curl($domain) {
		$xml = '';
		if(function_exists('curl_init')) {
			$url = $this->address;
			ob_start();
			$ch = curl_init();
			$timeout = 5;
			curl_setopt($ch, CURLOPT_URL, $url);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
			curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6");
			$xml = curl_exec($ch);
			curl_close($ch);
			ob_end_clean();
		}
		return $xml;
	}
}
?>