<?php
/**
 * WPSDCompeteRank. Ranking on compete.com.
 * @author dligthart <info@daveligthart.com>
 * @version 0.1
 * @package wp-stats-dashboard
 */
class WPSDCompeteRank extends WPSDStats {

	var $xml;
	var $values;
	var $address = '';
	var $home = 'http://snapshot.compete.com/';
	var $domain  = '';
	/**
	 * WPSDTechnoratiRank.
	 * @param string $domain
	 * @param boolean $curl
	 */
	function WPSDCompeteRank($domain, $curl = false) {
		parent::WPSDStats();

		$this->address = "http://api.compete.com/fast-cgi/MI?d={$domain}&ver=3&apikey=f4fqrkzqbn5upk375ru3fv35&size=large";

		$this->domain = $domain;

		if($this->isOutdated()) {
			if(!$curl){
				$this->xml = $this->get_data($domain);
			} else {
				$this->xml = $this->get_data_curl($domain);
			}
			$this->set();
		} else {
			$this->set_cached();
		}
	}

	/**
	 * Get data from alexa.
	 * @param string $domain
	 * @access public
	 */
	function get_data($domain) {
		$url = $this->address;
		$xml = file_get_contents($url);
		return $xml;
	}

	/**
	 * Set data.
	 * @access protected
	 */
	function set() {
		$rank = $this->getTagValue('ranking', $this->xml);
		$this->values['rank'] = ($rank !='')?$rank:0;

		$people = $this->getTagValue('count', $this->xml);
		$this->values['linksin'] = ($people != '')?$people:0;
		
		$this->set_cache('compete_rank', $this->values['rank']);
		$this->set_cache('compete_linksin', $this->values['linksin']);
	}
	
	function set_cached() {
		$this->values['rank'] = $this->get_cache('compete_rank');
		$this->values['linksin'] = $this->get_cache('compete_linksin');
	}
	
	/**
	 * Get tag value.
	 * @param string $tagname
	 * @access protected
	 */
	function getTagValue($tag, $xml) {
		$preg = "|<$tag>(.*?)</$tag>|s";
		preg_match_all($preg, $xml, $tags);
		return trim($tags[1][0]);
	}

	/**
	 * Get data.
	 * @return value
	 * @access protected
	 */
	function get($value){
		return (isset($this->values[$value]) ? $this->values[$value] : '0');
	}

	/**
	 * Get rank.
	 * @return rank
	 * @access public
	 */
	function getRank() {
		return $this->get('rank');
	}

	/**
	 * Get Links in.
	 * @return linksin
	 * @access public
	 */
	function getLinksIn() {
		return $this->get('linksin');
	}

	/**
	 * Get address.
	 * @return address
	 * @access public
	 */
	function getAddress() {
		return $this->address;
	}

	/**
	 * Get compete.com home address.
	 * @return url
	 * @access public
	 */
	function getHomeAddress() {
		$domain = str_replace('http://', '', $this->domain);
		$domain = str_replace('https://', '', $domain);
		$domain = str_replace('www.', '', $domain);
		return $this->home . $domain;
	}

	/**
	 * Get data by curl.
	 * @param string $domain
	 * @access public
	 */
	function get_data_curl($domain) {
		$xml = '';
		if(function_exists('curl_init')) {
			$url = $this->address;
			ob_start();
			$ch = curl_init();
			$timeout = 5;
			curl_setopt($ch, CURLOPT_URL, $url);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
			curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6");
			$xml = curl_exec($ch);
			curl_close($ch);
			ob_end_clean();
		}
		return $xml;
	}
}
?>