<?php
/**
 * WPSDDeliousRank. Number of incoming delicous bookmarks.
 * @author dligthart <info@daveligthart.com>
 * @version 0.2
 * @package wp-stats-dashboard
*/
class WPSDDeliciousRank extends WPSDStats {

	var $result;
	var $values;
	var $address = 'http://feeds.delicious.com/v2/json/urlinfo/data?hash=';
	var $domain =  '';

	/**
	 * WPSDDeliciousRank.
	 * @param string $domain
	 * @param boolean $curl
	 */
	function WPSDDeliciousRank($domain, $curl = false) {
		parent::WPSDStats();
		
		$this->domain = $domain;

		if(substr($domain, strlen($domain)-1) != '/') {
			$domain .= '/';
		}

		$this->address .= md5($domain);
		
		if($this->isOutdated()) {
			
			if(!$curl){
				$this->result = $this->get_data();
			} else {
				$this->result = $this->get_data_curl();
			}
			
			$this->set();
			
		} else {
			
			$this->set_cached();
		}
	}

	/**
	 * Get data from alexa.
	 * @param string $domain
	 * @access public
	 */
	function get_data() {
		$url = $this->address;
		$result = file_get_contents($url);
		return $result;
	}

	/**
	 * Set data.
	 */
	function set() {
		$this->values['linksin'] = $this->result->total_posts;
		
		$this->set_cache('del_rank', $this->values['linksin']);
	}
	
	function set_cached() {
		$this->values['linksin'] = $this->get_cache('del_rank');
	}

	/**
	 * Get data.
	 * @return value
	 * @access protected
	 */
	function get($value){
		return (isset($this->values[$value]) ? $this->values[$value] : '0');
	}

	/**
	 * Get Links in.
	 * @return linksin
	 * @access public
	 */
	function getLinksIn() {
		return $this->get('linksin');
	}

	/**
	 * Get home address.
	 * @return url
	 * @access public
	 */
	function getHomeAddress() {
		$domain = str_replace('http://', '', $this->domain);
		$domain = str_replace('https://', '', $domain);
		$domain = str_replace('www.', '', $domain);
		return 'http://delicious.com/search?p='.$domain.'&u=&chk=&context=&fr=del_icio_us&lc=0';
	}

	/**
	 * Get data by curl.
	 * @param string $domain
	 * @access public
	 */
	function get_data_curl() {
		$res = '';
		if(function_exists('curl_init')) {
			ob_start();
			$url = $this->address;
			$ch = curl_init();
			$timeout = 5;
			curl_setopt($ch,CURLOPT_URL, $url);
			curl_setopt($ch,CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch,CURLOPT_CONNECTTIMEOUT, $timeout);
			$temp = curl_exec($ch);
			curl_close($ch);
			ob_end_clean();

			$json = new Services_JSON();
			$result = $json->decode($temp);

			if($result != null && is_array($result)) {
				$res = $result[0];
			}
		}
		return $res;
	}
}
?>