<?php
/**
 * WPSDReddit.
 * @author dligthart <info@daveligthart.com>
 * @version 0.1
 * @package wp-stats-dashboard
 */
class WPSDReddit extends WPSDStats {

	var $xml;
	var $values;
	var $address = '';
	var $domain = '';
	
	/**
	 * WPSDReddit.
	 * @param string $domain
	 * @param boolean $curl
	 */
	function WPSDReddit($domain, $curl = false) {	
		parent::WPSDStats();

		$this->address = "http://www.reddit.com/api/info.json?url=" . $domain;
		
		$this->domain = $domain;
		
		if($this->isOutdated()) {
			if(!$curl){
				$this->xml = $this->get_data($domain);
			} else {
				$this->xml = $this->get_data_curl($domain);
			}
	
			$this->set();
		} else {
			$this->set_cached();
		}
	}

	/**
	 * Get data from alexa.
	 * @param string $domain
	 * @access public
	 */
	function get_data($domain) {
		$url = $this->address;
		$xml = file_get_contents($url);
		return $xml;
	}

	/**
	 * Set data.
	 */
	function set() {
	
		$json = new Services_JSON();

		$data = $json->decode($this->xml);
		
		$temp = $data->data->children[0];
		
		$score = $temp->data->score;
		
		$eng = $temp->data->num_comments;
				
		$this->values['score'] = $score;
		$this->values['eng'] = $eng;
		
		$this->set_cache('reddit_score', $score);
		$this->set_cache('reddit_eng', $eng);
	}
	
	function set_cached() {
		$this->values['score'] = $this->get_cache('reddit_score');
		$this->values['eng'] = $this->get_cache('reddit_eng');
	}

	/**
	 * Get data.
	 * @return value
	 * @access protected
	 */
	function get($value){
		return (isset($this->values[$value]) ? $this->values[$value] : '0');
	}

	/**
	 * Get rank.
	 * @return rank
	 * @access public
	 */
	function getRank() {
		return $this->get('score');
	}
	
	function getComments() {
		return $this->get('eng');
	}

	/**
	 * Get address.
	 * @return address
	 * @access public
	 */
	function getAddress() {
		return $this->address;
	}
	
	function getHomeAddress() {
		$domain = str_replace('http://', '', $this->domain);
		$domain = str_replace('https://', '', $domain);
		return 'http://www.reddit.com/' . $domain;
	}

	/**
	 * Get data by curl.
	 * @param string $domain
	 * @access public
	 */
	function get_data_curl($domain) {
		$xml = '';
		if(function_exists('curl_init')) {
			$url = $this->address;
			ob_start();
			$ch = curl_init();
			$timeout = 5;
			curl_setopt($ch, CURLOPT_URL, $url);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
			curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6");
			$xml = curl_exec($ch);
			curl_close($ch);
			ob_end_clean();
		}
		return $xml;
	}
}
?>