<?php
/**
 * WPSDSiteAge.
 * @author dligthart <info@daveligthart.com>
 * @version 0.2
 * @package wp-stats-dashboard
 */
class WPSDSiteAge extends WPSDStats {

	var $xml;
	var $values;
	var $address = '';

	/**
	 * WPSDSiteAge.
	 * @param string $domain
	 * @param boolean $curl
	 */
	function WPSDSiteAge($domain, $curl = false) {
		parent::WPSDStats();

		//$this->address = 'http://api.technorati.com/bloginfo?key=&url=' . $domain;
		//$domain = 'www.daveligthart.com';

		$domain = str_replace('http://', '', $domain);
		$domain = str_replace('https://', '', $domain);
		$url = trim($domain);
		$url = preg_replace("/^(http:\/\/)*(www.)*/is", "", $url);
		$url = preg_replace("/\/.*$/is" , "" ,$url);
		$domain = $url;
			
		$this->address = 'http://reports.internic.net/cgi/whois?whois_nic='.$domain.'&type=domain';

		if($this->isOutdated()) {
			if(!$curl){
				$this->xml = $this->get_data($domain);
			} else {
				$this->xml = $this->get_data_curl($domain);
			}

			$this->set();
		} else {
			$this->set_cached();
		}
	}

	/**
	 * Get data from alexa.
	 * @param string $domain
	 * @access public
	 */
	function get_data($domain) {
		$url = $this->address;
		$xml = file_get_contents($url);
		return $xml;
	}

	/**
	 * Set data.
	 */
	function set() {

		preg_match("@Creation Date:(.*?)Expiration Date@si", $this->xml, $matches);

		$creation_date = date('Y-m-d', strtotime($matches[1]));

		$a = strtotime($creation_date);
		$b = strtotime("now");
		$years = ( intval( ( $b - $a) / 86400) +1 ) / 365;

		if(null == $years) $years = 1;

		$this->values['age'] = $years;
		
		$this->set_cache('age', $years);
	}
	
	function set_cached() {
		$this->values['age'] = $this->get_cache('age');
	}
	
	/**
	 * Get data.
	 * @return value
	 * @access protected
	 */
	function get($value){
		return (isset($this->values[$value]) ? $this->values[$value] : '0');
	}

	/**
	 * Get rank.
	 * @return rank
	 * @access public
	 */
	function getAge() {
		return $this->get('age');
	}

	/**
	 * Get address.
	 * @return address
	 * @access public
	 */
	function getAddress() {
		return $this->address;
	}

	/**
	 * Get data by curl.
	 * @param string $domain
	 * @access public
	 */
	function get_data_curl($domain) {
		$xml = '';
		if(function_exists('curl_init')) {
			$url = $this->address;
			ob_start();
			$ch = curl_init();
			$timeout = 5;
			curl_setopt($ch, CURLOPT_URL, $url);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
			curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6");
			$xml = curl_exec($ch);
			curl_close($ch);
			ob_end_clean();
		}
		return $xml;
	}
}
?>