<?php
/**
 * WPSDTechnoratiRank. Ranking on Technorati.
 * @author dligthart <info@daveligthart.com>
 * @version 0.1
 * @package wp-stats-dashboard
 */
class WPSDTechnoratiRank extends WPSDStats {

	var $xml;
	var $values;
	var $address = '';

	/**
	 * WPSDTechnoratiRank.
	 * @param string $domain
	 * @param boolean $curl
	 */
	function WPSDTechnoratiRank($domain, $curl = false) {	
		parent::WPSDStats();

		//$this->address = 'http://api.technorati.com/bloginfo?key=&url=' . $domain;

		$domain = str_replace('http://', '', $domain);
		$domain = str_replace('https://', '', $domain);
		
		//$domain = 'www.daveligthart.com';
		
		$this->address = 'http://technorati.com/blogs/' . $domain;
		
		if($this->isOutdated()) {
			if(!$curl){
				$this->xml = $this->get_data($domain);
			} else {
				$this->xml = $this->get_data_curl($domain);
			}
	
			$this->set();
		} else {
			$this->set_cached();
		}
	}

	/**
	 * Get data from alexa.
	 * @param string $domain
	 * @access public
	 */
	function get_data($domain) {
		$url = $this->address;
		$xml = file_get_contents($url);
		return $xml;
	}

	/**
	 * Set data.
	 */
	function set() {
		//get the html code of the URL
		$html_values=$this->xml;

		ob_start();

		//get the string within <div class="rank"></div>
		preg_match("@<strong>Technorati Authority:(.*?)</strong>@si", $html_values, $matches);

		//strip out of the HTML element from the matches
		$rankvalue=strip_tags(trim($matches[1]));

		//geting the the rank values out of the string
		//preg_match("/(\d+(,\d+)?(,\d+)?)/", $rankvalue, $matches);

		//Set the rank.
		$this->values['rank'] = $rankvalue; //$matches[0];
		
		$this->set_cache('technorati_rank', $rankvalue);
		
		ob_end_clean();
	}
	
	function set_cached() {
		$this->values['rank'] = $this->get_cache('technorati_rank');
	}

	/**
	 * Get data.
	 * @return value
	 * @access protected
	 */
	function get($value){
		return (isset($this->values[$value]) ? $this->values[$value] : '0');
	}

	/**
	 * Get rank.
	 * @return rank
	 * @access public
	 */
	function getRank() {
		return $this->get('rank');
	}

	/**
	 * Get address.
	 * @return address
	 * @access public
	 */
	function getAddress() {
		return $this->address;
	}

	/**
	 * Get data by curl.
	 * @param string $domain
	 * @access public
	 */
	function get_data_curl($domain) {
		$xml = '';
		if(function_exists('curl_init')) {
			$url = $this->address;
			ob_start();
			$ch = curl_init();
			$timeout = 5;
			curl_setopt($ch, CURLOPT_URL, $url);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
			curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6");
			$xml = curl_exec($ch);
			curl_close($ch);
			ob_end_clean();
		}
		return $xml;
	}
}
?>