<?php
/**
 * WPSDTweetMeme.
 * @author dligthart <info@daveligthart.com>
 * @version 0.1
 * @package wp-stats-dashboard
 */
class WPSDTweetMeme extends WPSDStats {

	var $xml;
	var $values;
	var $address = '';
	var $address2 = '';
	/**
	 * WPSDTweetMeme.
	 * @param string $domain
	 * @param boolean $curl
	 */
	function WPSDTweetMeme($domain, $curl = false) {
		parent::WPSDStats();
		
		$this->address = 'http://api.tweetmeme.com/url_info.xml?url=' . $domain;
		
		$domain = str_replace('http://', '', $domain);
		$domain = str_replace('https://', '', $domain);
		$domain = str_replace('www.', '', $domain);
		
		$this->address2 = 'http://tweetmeme.com/search?q=' . $domain;
		
		if($this->isOutdated()) {
			if(!$curl){
				$this->xml = $this->get_data($domain);
			} else {
				$this->xml = $this->get_data_curl($domain);
			}
	
			$this->set();
		} else {
			$this->set_cached();
		}
	}
	
	/**
	 * Set data.
	 */
	function set() {
		
		preg_match("@<url_count>(.*?)</url_count>@si", $this->xml, $matches);
	
		$this->values['count'] = number_format($matches[1]);
		
		preg_match("@<tm_link>(.*?)</tm_link>@si", $this->xml, $matches2);
		
		$this->address2 = $matches2[1];
		
		$this->set_cache('tweets', $this->values['count']);
		
		$this->set_cache('tm_addr', $this->address2);
	}
	
	function set_cached() {
		
		$this->values['count'] = $this->get_cache('tweets');
		
		$this->address2 = $this->get_cache('tm_addr');
	}
	
	/**
	 * Get data.
	 * @return value
	 * @access protected
	 */
	function get($value){
		return (isset($this->values[$value]) ? $this->values[$value] : '0');
	}

	/**
	 * Get rank.
	 * @return rank
	 * @access public
	 */
	function getCount() {
		return $this->get('count');
	}

	/**
	 * Get address.
	 * @return address
	 * @access public
	 */
	function getAddress() {
		return $this->address2;
	}

	/**
	 * Get data by curl.
	 * @param string $domain
	 * @access public
	 */
	function get_data_curl($domain) {
		$xml = '';
		if(function_exists('curl_init')) {
			$url = $this->address;
			ob_start();
			$ch = curl_init();
			$timeout = 5;
			curl_setopt($ch, CURLOPT_URL, $url);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
			curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6");
			$xml = curl_exec($ch);
			curl_close($ch);
			ob_end_clean();
		}
		return $xml;
	}
}
?>