<?php
/**
 * WPSDYahooRank. Ranking based on number of incoming links.
 * @author dligthart <info@daveligthart.com>
 * @version 0.1
 * @package wp-stats-dashboard
 */
class WPSDYahooRank extends WPSDStats {

	var $xml;
	var $values;
	var $address = 'http://search.yahooapis.com/SiteExplorerService/V1/inlinkData?appid=c16bCwrV34GNSmI05no_7uRU89ME_fvJ8G8958jsdclgZl8MJHCebcluFX6RsHj0&output=php&query=';
	var $home = 'http://siteexplorer.search.yahoo.com/search?y=Explore+URL&fr=sfp&p=';
	var $domain  = '';

	/**
	 * WPSDTechnoratiRank.
	 * @param string $domain
	 * @param boolean $curl
	 */
	function WPSDYahooRank($domain, $curl = false) {
		parent::WPSDStats();
		
		$this->address .= $domain;

		$this->domain = $domain;
		
		if($this->isOutdated()) {
			if(!$curl){
				$this->xml = $this->get_data($domain);
			} else {
				$this->xml = $this->get_data_curl($domain);
			}
			$this->set();
		} else {
			$this->set_cached();
		}
	}

	/**
	 * Get data from alexa.
	 * @param string $domain
	 * @access public
	 */
	function get_data($domain) {
		$url = $this->address;
		$xml = file_get_contents($url);
		return $xml;
	}

	/**
	 * Set data.
	 * @access protected
	 */
	function set() {
		$linksin = $this->xml['ResultSet']['totalResultsAvailable'];
		$this->values['linksin'] = ($linksin != '')?$linksin:0;
		
		$this->set_cache('yahoo_linksin', $this->values['linksin']);
	}
	
	function set_cached() {
		$this->values['linksin'] = $this->get_cache('yahoo_linksin');
	}

	/**
	 * Get data.
	 * @return value
	 * @access protected
	 */
	function get($value){
		return (isset($this->values[$value]) ? $this->values[$value] : '0');
	}

	/**
	 * Get rank.
	 * @return rank
	 * @access public
	 */
	function getRank() {
		return $this->get('rank');
	}

	/**
	 * Get Links in.
	 * @return linksin
	 * @access public
	 */
	function getLinksIn() {
		return $this->get('linksin');
	}

	/**
	 * Get address.
	 * @return address
	 * @access public
	 */
	function getAddress() {
		return $this->address;
	}

	/**
	 * Get compete.com home address.
	 * @return url
	 * @access public
	 */
	function getHomeAddress() {
		return $this->home . $this->domain;
	}

	/**
	 * Get data by curl.
	 * @param string $domain
	 * @access public
	 */
	function get_data_curl($domain) {
		$res = '';
		if(function_exists('curl_init')) {
			$url = $this->address;
			ob_start();
			$ch = curl_init();
			$timeout = 5;
			curl_setopt($ch, CURLOPT_URL, $url);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
			curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.6");
			$res = curl_exec($ch);
			curl_close($ch);
			ob_end_clean();
			$res = unserialize($res);
		}
		return $res;
	}
}
?>